package xhttp3.internal.tls;

import javax.security.auth.x500.X500Principal;

final class DistinguishedNameParser {
   private final String dn;
   private final int length;
   private int pos;
   private int beg;
   private int end;
   private int cur;
   private char[] chars;

   public DistinguishedNameParser(X500Principal principal) {
      DistinguishedNameParser var10000 = this;
      super();
      String var2;
      this.dn = var2 = principal.getName("RFC2253");
      var10000.length = var2.length();
   }

   private String nextAT() {
      int var1;
      int var2;
      while((var1 = this.pos) < (var2 = this.length) && this.chars[var1] == ' ') {
         this.pos = var1 + 1;
      }

      if (var1 == var2) {
         return null;
      } else {
         this.beg = var1;

         char[] var3;
         for(this.pos = var1 + 1; (var1 = this.pos) < (var2 = this.length) && (var3 = this.chars)[var1] != '=' && var3[var1] != ' '; this.pos = var1 + 1) {
         }

         if (var1 >= var2) {
            throw new IllegalStateException("Unexpected end of DN: " + this.dn);
         } else {
            this.end = var1;
            if (this.chars[var1] == ' ') {
               while((var1 = this.pos) < (var2 = this.length) && (var3 = this.chars)[var1] != '=' && var3[var1] == ' ') {
                  this.pos = var1 + 1;
               }

               if (this.chars[var1] != '=' || var1 == var2) {
                  throw new IllegalStateException("Unexpected end of DN: " + this.dn);
               }
            }

            ++this.pos;

            while((var1 = this.pos) < this.length && this.chars[var1] == ' ') {
               this.pos = var1 + 1;
            }

            char[] var5;
            if (this.end - (var1 = this.beg) > 4 && (var5 = this.chars)[var1 + 3] == '.' && (var5[var1] == 'O' || var5[var1] == 'o') && (var5[var1 + 1] == 'I' || var5[var1 + 1] == 'i') && (var5[var1 + 2] == 'D' || var5[var1 + 2] == 'd')) {
               this.beg = var1 + 4;
            }

            char[] var4 = this.chars;
            var2 = this.beg;
            return new String(var4, var2, this.end - var2);
         }
      }
   }

   private String quotedAV() {
      int var1;
      this.pos = var1 = this.pos + 1;
      this.beg = var1;

      for(this.end = var1; (var1 = this.pos) != this.length; ++this.end) {
         char[] var2;
         int var3;
         if ((var2 = this.chars)[var1] == '"') {
            for(this.pos = var1 + 1; (var1 = this.pos) < this.length && this.chars[var1] == ' '; this.pos = var1 + 1) {
            }

            char[] var4 = this.chars;
            var3 = this.beg;
            return new String(var4, var3, this.end - var3);
         }

         if (var2[var1] == '\\') {
            var1 = this.end;
            var2[var1] = this.getEscaped();
         } else {
            var3 = this.end;
            var2[var3] = var2[var1];
         }

         ++this.pos;
      }

      throw new IllegalStateException("Unexpected end of DN: " + this.dn);
   }

   private String hexAV() {
      int var1;
      if ((var1 = this.pos) + 4 >= this.length) {
         throw new IllegalStateException("Unexpected end of DN: " + this.dn);
      } else {
         this.beg = var1;
         this.pos = var1 + 1;

         label58:
         while(true) {
            char[] var2;
            if ((var1 = this.pos) == this.length || (var2 = this.chars)[var1] == '+' || var2[var1] == ',' || var2[var1] == ';') {
               this.end = var1;
               break;
            }

            if (var2[var1] == ' ') {
               this.end = var1;
               this.pos = var1 + 1;

               while(true) {
                  if ((var1 = this.pos) >= this.length || this.chars[var1] != ' ') {
                     break label58;
                  }

                  this.pos = var1 + 1;
               }
            }

            if (var2[var1] >= 'A' && var2[var1] <= 'F') {
               var2[var1] = (char)(var2[var1] + 32);
            }

            this.pos = var1 + 1;
         }

         int var7;
         if ((var7 = this.end - (var1 = this.beg)) >= 5 && (var7 & 1) != 0) {
            int var3;
            byte[] var4 = new byte[var3 = var7 / 2];
            int var5 = 0;
            ++var1;

            while(var5 < var3) {
               var4[var5] = (byte)this.getByte(var1);
               var1 += 2;
               ++var5;
            }

            char[] var6 = this.chars;
            return new String(var6, this.beg, var7);
         } else {
            throw new IllegalStateException("Unexpected end of DN: " + this.dn);
         }
      }
   }

   private String escapedAV() {
      int var1;
      this.beg = var1 = this.pos;
      this.end = var1;

      int var4;
      char[] var5;
      while((var1 = this.pos) < this.length) {
         int var10001;
         char[] var2;
         char var3;
         if ((var3 = (var2 = this.chars)[var1]) != ' ') {
            if (var3 != ';') {
               if (var3 == '\\') {
                  this.end = (var1 = this.end) + 1;
                  var2[var1] = this.getEscaped();
                  var10001 = this.pos++;
                  continue;
               }

               if (var3 != '+' && var3 != ',') {
                  var10001 = var1;
                  int var10004 = var1;
                  this.end = (var1 = this.end) + 1;
                  var2[var1] = var2[var10004];
                  this.pos = var10001 + 1;
                  continue;
               }
            }

            var5 = this.chars;
            var4 = this.beg;
            return new String(var5, var4, this.end - var4);
         } else {
            char[] var10000 = var2;
            int var10002 = var4 = this.end;
            this.cur = var4;
            this.pos = var1 + 1;
            this.end = var10002 + 1;

            char[] var6;
            for(var10000[var4] = ' '; (var1 = this.pos) < (var4 = this.length) && (var6 = this.chars)[var1] == ' '; this.pos = var10001 + 1) {
               var10001 = var1;
               this.end = (var1 = this.end) + 1;
               var6[var1] = ' ';
            }

            if (var1 == var4 || (var2 = this.chars)[var1] == ',' || var2[var1] == '+' || var2[var1] == ';') {
               var5 = this.chars;
               var4 = this.beg;
               return new String(var5, var4, this.cur - var4);
            }
         }
      }

      var5 = this.chars;
      var4 = this.beg;
      return new String(var5, var4, this.end - var4);
   }

   private char getEscaped() {
      int var1;
      int var10000 = var1 = this.pos + 1;
      this.pos = var1;
      if (var10000 != this.length) {
         char[] var2;
         switch ((var2 = this.chars)[var1]) {
            case ' ':
            case '"':
            case '#':
            case '%':
            case '*':
            case '+':
            case ',':
            case ';':
            case '<':
            case '=':
            case '>':
            case '\\':
            case '_':
               return var2[var1];
            default:
               return this.getUTF8();
         }
      } else {
         throw new IllegalStateException("Unexpected end of DN: " + this.dn);
      }
   }

   private char getUTF8() {
      int var1;
      int var10000 = var1 = this.getByte(this.pos);
      ++this.pos;
      if (var10000 < 128) {
         return (char)var1;
      } else if (var1 >= 192 && var1 <= 247) {
         int var2;
         byte var5;
         if (var1 <= 223) {
            var5 = 1;
            var2 = var1 & 31;
         } else if (var1 <= 239) {
            var5 = 2;
            var2 = var1 & 15;
         } else {
            var5 = 3;
            var2 = var1 & 7;
         }

         for(int var3 = 0; var3 < var5; ++var3) {
            int var4;
            var10000 = var4 = this.pos + 1;
            this.pos = var4;
            if (var10000 == this.length || this.chars[var4] != '\\') {
               return '?';
            }

            this.pos = ++var4;
            var10000 = var4 = this.getByte(var4);
            ++this.pos;
            if ((var10000 & 192) != 128) {
               return '?';
            }

            var2 = (var2 << 6) + (var4 & 63);
         }

         return (char)var2;
      } else {
         return '?';
      }
   }

   private int getByte(int position) {
      int var2;
      if ((var2 = position + 1) >= this.length) {
         throw new IllegalStateException("Malformed DN: " + this.dn);
      } else {
         char[] var3;
         char position1;
         if ((position1 = (var3 = this.chars)[position]) >= '0' && position1 <= '9') {
            position = position1 - 48;
         } else if (position1 >= 'a' && position1 <= 'f') {
            position = position1 - 87;
         } else {
            if (position1 < 'A' || position1 > 'F') {
               throw new IllegalStateException("Malformed DN: " + this.dn);
            }

            position = position1 - 55;
         }

         int var4;
         char var6;
         if ((var6 = var3[var2]) >= '0' && var6 <= '9') {
            var4 = var6 - 48;
         } else if (var6 >= 'a' && var6 <= 'f') {
            var4 = var6 - 87;
         } else {
            if (var6 < 'A' || var6 > 'F') {
               throw new IllegalStateException("Malformed DN: " + this.dn);
            }

            var4 = var6 - 55;
         }

         return (position << 4) + var4;
      }
   }

   public String findMostSpecific(String attributeType) {
      this.pos = 0;
      this.beg = 0;
      this.end = 0;
      this.cur = 0;
      this.chars = this.dn.toCharArray();
      String var2;
      if ((var2 = this.nextAT()) == null) {
         return null;
      } else {
         do {
            String var3 = "";
            int var4;
            if ((var4 = this.pos) == this.length) {
               return null;
            }

            char var6;
            if ((var6 = this.chars[var4]) != '"') {
               if (var6 != '#') {
                  if (var6 != '+' && var6 != ',' && var6 != ';') {
                     var3 = this.escapedAV();
                  }
               } else {
                  var3 = this.hexAV();
               }
            } else {
               var3 = this.quotedAV();
            }

            if (attributeType.equalsIgnoreCase(var2)) {
               return var3;
            }

            int var5;
            if ((var5 = this.pos) >= this.length) {
               return null;
            }

            char[] var7;
            if ((var7 = this.chars)[var5] != ',' && var7[var5] != ';' && var7[var5] != '+') {
               throw new IllegalStateException("Malformed DN: " + this.dn);
            }

            this.pos = var5 + 1;
         } while((var2 = this.nextAT()) != null);

         throw new IllegalStateException("Malformed DN: " + this.dn);
      }
   }
}
